Charm for IBM WebSphere Application Server ND Node (WAS ND Node) 8.5.5.0

## Overview

IBM WebSphere Application Server Network Deployment provides an advanced, flexible runtime environment for large-scale application deployments. It offers near-continuous availability with advanced performance and management capabilities for mission-critical applications. For details on IBM Websphere Application Server Network Deployment,  as well as information on purchasing, please visit [Product Page][WAS-ND-product-page] and at the [Passport Advantage Site] [Passport-Advantage]. More information available at the [IBM Knowledge Center] [WAS-ND-Infocenter].

`IBM WebSphere Application Server ND Node`

This charm is using IBM WAS ND charm as a basic layer to install IBM WAS ND Software. After WAS ND installation, this charm will creates custom profiles (cluster members) to configure dynamic cluster setup.

**Please note that the WAS ND charms (WAS ND, WAS ND DM and WAS ND Node) will create IBM WAS ND dynamic cluster.

## Prerequisites

This charm makes use of resources, a feature only available in Juju 2.0. During deploy or upgrade, you will need to specify the installable package(s) required by this charm. Download your licensed IBM WebSphere Application Server ND packages from the [Product Page][WAS-ND-8.5.5.0-download].

### Packages for Ubuntu on AMD64 (x86_64):

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.x86_64_1.8.3000.20150606_0047.zip`)

IBM WAS ND 8.5.5 part1 (WASND_v8.5.5_1of3.zip)

IBM WAS ND 8.5.5 part2 (WASND_v8.5.5_2of3.zip)

IBM WAS ND 8.5.5 part3 (WASND_v8.5.5_3of3.zip)

### Packages for Ubuntu on Power (ppc64le):

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.ppc64le_1.8.3000.20150606_0047.zip`)

IBM WAS ND 8.5.5 part1 (WAS_ND_V8.5.5_FOR_POWERLE_ML.zip)

IBM WAS ND 8.5.5 part2 (WASND_V8.5.5_2OF_2_FOR_POWERLE_ML.zip)

## Usage

To use this charm, you must agree to the Terms of Use. You can view the full license for `IBM Installation Manager` and `IBM WebSphere Application Server Network Deployment` products by visiting the [im-license-info](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/39AFC1C1D485C4E085257E7300548B05?OpenDocument) and [was-nd-license-info] [license-info] page.

Search for "IBM WebSphere Application Server Network Deployment" and choose the license that applies to the version you are using.


## Memory and Disk Requirements

Minimum 2.0 GB of disk space for installed image and Minimum 1 GB of physical memory recommended. 

WebSphere Application Server ND Charm requires 15 GB of root disk to download packages and install the IBM WebSphere Application Server ND Software. By default available root disk space is 8GB.

To request a larger root disk, run the following command:

		juju set-constraints root-disk=15G

### Deploy

This charm will deploy `WAS ND Nodes` to configure WAS ND dynamic cluster. WAS ND node will act as a cluster member. When you add relation between WAS ND DM and WAS ND Node charms, WAS ND DM charm creates the dynamic cluster and Node will be added as a cluster member.

1. Deploy the WAS ND DM charm:

	juju deploy ibm-was-nd-dm --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_was_nd_installer1=</path/to/ibm_was_nd_installer1.zip> --resource ibm_was_nd_installer2=</path/to/ibm_was_nd_installer2.zip> --resource ibm_was_nd_installer3=</path/to/ibm_was_nd_installer3.zip>

2. Deploy the WAS ND Node charm:

	juju deploy ibm-was-nd-node --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_was_nd_installer1=</path/to/ibm_was_nd_installer1.zip> --resource ibm_was_nd_installer2=</path/to/ibm_was_nd_installer2.zip> --resource ibm_was_nd_installer3=</path/to/ibm_was_nd_installer3.zip>
		
													OR
													
	juju deploy -n <num> ibm-was-nd-node --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_was_nd_installer1=</path/to/ibm_was_nd_installer1.zip> --resource ibm_was_nd_installer2=</path/to/ibm_was_nd_installer2.zip> --resource ibm_was_nd_installer3=</path/to/ibm_was_nd_installer3.zip>
		
	where <num> is the number of WAS ND Node units you want to deploy
		
3. Add a relation between WAS ND DM and WAS ND Node

	juju add-relation ibm-was-nd-dm ibm-was-nd-node
	
This will create WAS ND Node host which is ready to add more hosts to the WAS ND cluster. To add more units of WAS ND Node, you can use `add-unit` to add more hosts to your WAS ND cluster (each added unit will be designated as new cluster member).

        juju add-unit ibm-was-nd-node

This command will add a WAS ND Node to your existing WAS ND cluster.

**Note**: This charm requires acceptance of Terms of Use. When deploying from the Charm Store, these terms will be presented to you for your consideration.

To accept the terms:

		juju agree ibm-im/1 ibm-was-nd/1
		juju deploy ibm-was-nd-node

4. To Expose the IBM WAS ND Node Service to public, run the following command:

		juju expose ibm-was-nd-node


### Upgrade

Once deployed, user can upgrade the existing installation by installing fixpacks:

If user wants to upgrade existing installation of Installtion Manger, run the following command:

    juju attach ibm-was-nd-node ibm_im_fixpack=</path/to/fixpack.zip>

To upgrade WAS ND Node installation:
	
	juju attach ibm-was-nd-node ibm_was_nd_fp1=</path/to/ibm_was_nd_fp1.zip>
	juju attach ibm-was-nd-node ibm_was_nd_fp2=</path/to/ibm_was_nd_fp2.zip>

**Note**: WAS ND DM and WAS ND Node installation should be in same level(If you wan to upgrade WAS ND Node installation make sure that WAS ND DM also upgraded with same fixpack version). 

### Verification Of WAS ND Cluster

Once the IBM WAS ND Node is deployed successfully and relation is established between WAS ND DM and WAS ND Node, you can verify your WAS ND cluster by using below URLs.

1. Login to DM console:

	http://was-nd-dm-host:9060/ibm/console 
	https://was-nd-dm-host:9043/ibm/console
	
2. In the DM console click Servers > Clusters > Dynamic clusters > <dynamic_cluster_name>. On right side, click dynamic cluster members and verify the status of the cluster members. All cluster members should be started.
	
Here was-nd-dm-host represents the public ip address of your machine, where WAS ND DM is installed. 
		

## IBM WebSphere Application Server Network Deployment Information

(1) General Information 

Details about IBM WAS ND software available at [IBM Knowledge Center] [WAS-ND-Infocenter].

Information on procuring WAS ND product is available at the [Passport Advantage site] [Passport-Advantage]

(2) Download Information

Details about WAS ND 8.5.5.0 download available [here] [[WAS-ND-8.5.5.0-download]

Information about installation of WAS ND on 'ppc64le' based machine available [here] [WAS-ND-for-ppc64le]  

More information about IBM IM Downloadable file and WAS ND downloadable files available [here] [IBM-IM-more-info]

## Contact Information

For issues with this charm, please contact IBM Juju Support team <jujusupp@us.ibm.com>

<!-- Links -->

[WAS-ND-Infocenter]: http://www-01.ibm.com/support/knowledgecenter/SSAW57_8.5.5/as_ditamaps/was855_welcome_ndmp.html?lang=en

[WAS-ND-product-page]: http://www-03.ibm.com/software/products/en/appserv-wasnd

[WAS-ND-8.5.5.0-download]: http://www-01.ibm.com/support/docview.wss?uid=swg27038624

[Passport-Advantage]: http://www-01.ibm.com/software/passportadvantage/

[IBM-IM-more-info]: http://www-01.ibm.com/support/docview.wss?uid=swg24038380

[WAS-ND-for-ppc64le]: http://www-304.ibm.com/support/knowledgecenter/SSEQTP_8.5.5/com.ibm.websphere.installation.nd.doc/ae/cins_offerings.html?lang=en-us

[WAS-ppc64le-fixpack-info]: http://www-01.ibm.com/support/docview.wss?uid=swg24040035

[license-info]: http://www-03.ibm.com/software/sla/sladb.nsf/lilookup/6CCA78CD870DCA5985257D90005A5351?OpenDocument
