#!/bin/bash
set -ex

source charms.reactive.sh
reactive_states=`charms.reactive -y get_states`

WAS_ND_INSTALL_PATH=/root/IBM/WebSphere/AppServer/V85/ND
IM_INSTALL_PATH=/opt/IBM/InstallationManager
profile_template_path="$WAS_ND_INSTALL_PATH/profileTemplates/default"
hostname=`unit-get private-address`
ARCHITECTURE=`uname -m`
dm_username=""
dm_password=""
juju-log "IBM WAS ND Node: host name is $hostname"
profile_name="_profile"
profile_name=$hostname$profile_name
juju-log "profile name is $profile_name"

if [ -f $CHARM_DIR/files/dm_credentials.txt ]; then
		source $CHARM_DIR/files/dm_credentials.txt
		dm_username=$username
		dm_password=$password
fi

install_was_nd_fixpack() {
	if [ "$ARCHITECTURE" == "x86_64" ];then
		if $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.ND.v85 -acceptLicense -repositories $CHARM_DIR/../resources/WAS_ND/FP -installationDirectory $WAS_ND_INSTALL_PATH  -showProgress
		then
			set_state 'ibm-was-nd-node.updated'
			status-set active "IBM WAS ND: WAS ND installation upgraded successfully!"
		else
			status-set blocked "IBM WAS ND: Error while upgrading WAS ND!"
			exit 1
		fi
                          
	elif [ "$ARCHITECTURE" == "ppc64le" ];then
		if $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.ND.le.v85 -acceptLicense -repositories $CHARM_DIR/../resources/WAS_ND/FP -installationDirectory $WAS_ND_INSTALL_PATH  -showProgress
		then
			set_state 'ibm-was-nd-node.updated'
			status-set active "IBM WAS ND: WAS ND installation upgraded successfully!"
		else
			status-set blocked "IBM WAS ND: Error while upgrading WAS ND!"
			exit 1
		fi
	fi
}

@when 'ibm-was-nd.installed'
@when_not 'ibm-was-nd-node.profile.ready'
function create_default_profile(){
		juju-log "IBM WAS ND: Checking etc/hosts file."
	private_address=`unit-get private-address`
	juju-log "private_address : $private_address"
	cd /etc
	if grep -q "$private_address" hosts
	then
		juju-log "IBM WAS ND: Host file already updated"
	else
		juju-log "IBM WAS ND: Updating Host file"
		echo "$private_address `hostname`" >> /etc/hosts
	fi
	juju-log "IBM WAS ND Node: Creating custom profile to federate."
	$WAS_ND_INSTALL_PATH/bin/manageprofiles.sh -create -profileName $profile_name -templatePath $profile_template_path 
	juju-log "IBM WAS ND Node: Profile creation completed."
	set_state 'ibm-was-nd-node.profile.ready'
}

@when 'ibm-was-nd.installed'
@when_not 'ibm-was-nd-node.updated'
function update_was_nd_node(){
	
	# Get the WAS ND fixpack resources
	juju-log "IBM WAS ND: fetching the ibm_was_nd_fp1 resource"
	status-set maintenance "fetching the ibm_was_nd_fp1 resource"
	was_nd_fp1=`resource-get 'ibm_was_nd_fp1' || echo unavailable`
		
	juju-log "IBM WAS ND: fetching the ibm_was_nd_fp2 resource"
	status-set maintenance "fetching the ibm_was_nd_fp2 resource"
	was_nd_fp2=`resource-get 'ibm_was_nd_fp2' || echo unavailable`
		
	#If we don't have a fixpack, just exit successfully; there's nothing to do.
	if [ "$was_nd_fp1" = "unavailable" -o "$was_nd_fp2" = "unavailable" ]; then
		juju-log "IBM WAS ND: no ibm_was_nd_fixpack packages to install"
		status-set active "IBM WAS ND is ready"
		return 0
	fi
	
	#If we detect the fixpack is just a placeholder in charm store, just exit successfully; there's nothing to do.
	ibm_was_fp1_isempty=`file $WAS_ND_fp1 | { grep -q empty && echo "True"; } || echo "False"`
	ibm_was_fp2_isempty=`file $WAS_ND_fp2 | { grep -q empty && echo "True"; } || echo "False"`
	if [ "$ibm_was_fp1_isempty" = "True" -o "$ibm_was_fp2_isempty" = "True" ]; then
		juju-log "IBM WAS ND: no ibm_was_nd_fixpack packages to install"
		status-set active "IBM WAS ND is ready"
		return 0
	fi
	was_fixpack_packages="$was_nd_fp1 $was_nd_fp2"
	juju-log "IBM WAS ND: Fixpacks provided for upgrade $was_fixpack_packages"
	
	if [ ! -d $CHARM_DIR/../resources/WAS_ND/FP ]; then
		mkdir $CHARM_DIR/../resources/WAS_ND/FP
	fi
	
	for was_fp_pkg in $was_fixpack_packages; do
		juju-log "was_fp_pkg====="$was_fp_pkg
		if [ -f $was_fp_pkg ]; then
			ARCHIVE_DIR=`dirname $was_fp_pkg`
			juju-log "IBM WAS ND: extracting the ibm_was_nd_fp resources"
			status-set maintenance "extracting the ibm_was_nd_fp resources"
			if ! unzip $was_fp_pkg -d $ARCHIVE_DIR/../WAS_ND/FP
				then
					juju-log "IBM WAS ND: Unable to extract the WAS ND fixpack content. Verify whether the package is corrupt."
					# Remove corrupt archive file
					status-set blocked "IBM WAS ND packages are corrupt"
					rm -rf $ARCHIVE_DIR/../WAS_ND/FP
					exit 0
			else
				juju-log "IBM WAS ND: $was_fp_pkg extracted successfully"
			fi
		fi
	done
	if charms.reactive is_state 'ibm-was-nd-node.added'; then
		remove_from_cluster
	fi

	install_was_nd_fixpack
}

@hook 'upgrade-charm'
function check_fixpack(){
	# The upgrade-charm hook will fire when a new resource is pushed for this
	# charm. This is a good time to determine if we need to deal with a new
	# fixpack.
	if ! charms.reactive is_state 'ibm-was-nd-node.updated'; then
		# If there is no prior fixpack installed (because ibm-was-nd-node.updated is not
		# set), do nothing since update_was_nd_node will handle that case.
		juju-log "IBM WAS ND: no fixpack has been installed; nothing to upgrade."
		exit 0
	else
		# If we have a fixpack packges already (because ibm-was-nd.updated is set),
		# we should fetch the latest fixpack packages and determine if it is new.
		#  - If it is new, set our states so install_was_nd_fixpack is called again
		#  - If it is not new, do nothing
		juju-log "IBM WAS ND: scanning for new fixpacks to install"
		WAS_FP1_DIR="$CHARM_DIR/../resources/ibm_was_nd_fp1"
		WAS_FP2_DIR="$CHARM_DIR/../resources/ibm_was_nd_fp2"
		CUR_FP1="$WAS_FP1_DIR/ibm_was_nd_fp1.zip"
		CUR_FP2="$WAS_FP2_DIR/ibm_was_nd_fp2.zip"
		if [ -f $CUR_FP1 -a -f  $CUR_FP2 ]; then
			CUR_FP1_MD5=`md5sum "$CUR_FP1" | awk '{print $1}'`
			CUR_FP2_MD5=`md5sum "$CUR_FP2" | awk '{print $1}'`
		fi
		NEW_FP1=`resource-get 'ibm_was_nd_fp1' || echo unavailable`
		NEW_FP2=`resource-get 'ibm_was_nd_fp2' || echo unavailable`
		
		if [ "$NEW_FP1" = "unavailable" -o "$NEW_FP2" = "unavailable" ]; then
			juju-log "IBM WAS ND: no fixpacks to install"
		elif [ -f $NEW_FP1 -a -f  $NEW_FP2 ]; then
			NEW_FP1_MD5=`md5sum "$NEW_FP1" | awk '{print $1}'`
			NEW_FP2_MD5=`md5sum "$NEW_FP2" | awk '{print $1}'`
		fi
		
		if [ "$CUR_FP1_MD5" != "$NEW_FP1_MD5" -o "$CUR_FP2_MD5" != "$NEW_FP2_MD5" ]; then
			juju-log "IBM WAS ND: new fixpack detected ($CUR_FP1 with $CUR_FP1_MD5 versus $NEW_FP1 with $NEW_FP1_MD5 and $CUR_FP2 with $CUR_FP2_MD5 versus $NEW_FP2 with $NEW_FP2_MD5)"
			rm -rf $CHARM_DIR/../resources/WAS_ND/FP
			remove_state 'ibm-was-nd-node.updated'
		else
			juju-log "IBM WAS ND: no new fixpack to install"
		fi
	fi
}

@when 'ibm-was-nd-node.profile.ready' 'cluster-node.connected'
@when_not 'ibm-was-nd-node.hostname.set'
function set_node_host_name(){
	node_host_name=`hostname`
	relation_call --state=cluster-node.connected set_was_node_hostname $node_host_name || true
	set_state 'ibm-was-nd-node.hostname.set'
}

@when 'ibm-was-nd-node.profile.ready' 'cluster-node.ready'
@when_not 'ibm-was-nd-node.added'
function add_was_nd_node(){
	juju-log "*******In add_was_nd_node reactive function of WAS ND Node charm*******"
	dm_host=$(relation_call --state=cluster-node.connected get_was_dm_hostname) || true
	juju-log "I got the dm host name $dm_host"
	if [ "$dm_host" == "None" ]; then
		juju-log "IBM WAS Node: Waiting for the data......."
		return 0
	else
	juju-log "IBM WAS ND Node: got dmgr host $dm_host"
	cd /etc
		if grep -q "$dm_host" hosts
		then
			juju-log "IBM WAS ND Node: Host file already updated"
		else
			juju-log "IBM WAS ND Node: Updating Host file"
			echo "$dm_host dmgr_host" >> /etc/hosts
		fi
	fi
	dm_username=$(relation_call --state=cluster-node.connected get_dmgradminuser) || true
	juju-log "I got the dm user name $dm_username"
	dm_password=$(relation_call --state=cluster-node.connected get_dmgrpwd) || true
	juju-log "I got the dm password $dm_password"
	if [ ! -d $CHARM_DIR/files ]; then
		mkdir $CHARM_DIR/files
	fi
	if [ ! -f $CHARM_DIR/files/dm_credentials.txt ]; then
		touch $CHARM_DIR/files/dm_credentials.txt
		echo "username=$dm_username" >> $CHARM_DIR/files/dm_credentials.txt
		echo "password=$dm_password" >> $CHARM_DIR/files/dm_credentials.txt
	fi
	if $WAS_ND_INSTALL_PATH/profiles/$profile_name/bin/addNode.sh $dm_host -username $dm_username -password $dm_password
	then
		$WAS_ND_INSTALL_PATH/profiles/$profile_name/bin/startServer.sh server1
		juju-log "Profile Federated to deployment manager."
		set_state 'ibm-was-nd-node.added'
	else
		juju-log "IBM WAS ND Node: Error occured while adding node to the deployment manager."
		exit 1
	fi
}

@when 'cluster-node.departed'
function remove_from_cluster(){
	juju-log "*******In remove_from_cluster reactive function of WAS ND Node charm*******"
	juju-log "Removing Federated profile from deployment manager cell"
	#dm_username=$(relation_call --state=cluster-node.departed get_dmgradminuser) || true
	juju-log "I got the dm user name $dm_username"
	#dm_password=$(relation_call --state=cluster-node.departed get_dmgrpwd) || true
	juju-log "I got the dm password $dm_password"
	if $WAS_ND_INSTALL_PATH/profiles/$profile_name/bin/removeNode.sh -username $dm_username -password $dm_password
	then
		juju-log "Removed Federated profile from deployment manager cell"
		rm -rf $CHARM_DIR/files/dm_credentials.txt
	else
		juju-log "IBM WAS ND Node: Error occured while removing node from the deployment manager."
		exit 1
	fi
	remove_state 'ibm-was-nd-node.added'
	
}
reactive_handler_main

