#!/bin/bash
set -ex

source charms.reactive.sh

WAS_ND_INSTALL_PATH=/root/IBM/WebSphere/AppServer/V85/ND
IM_INSTALL_PATH=/opt/IBM/InstallationManager
ARCHITECTURE=`uname -m`

if [ "$ARCHITECTURE" != "x86_64" -a  "$ARCHITECTURE" != "ppc64le" ]; then
	juju-log "IBM WAS ND: Unsupported platform. IBM WAS ND installed with this Charm supports only the x86_64 and ppc64le platforms."
	status-set blocked "IBM WAS ND: Unsupported architecture"
	exit 1
fi

@when 'ibm-im.installed'
@when_not 'ibm-was-nd.installed'
function install_WAS_ND() {
	juju-log "IBM WAS ND: Checking etc/hosts file."
	private_address=`unit-get private-address`
	juju-log "private_address : $private_address"
#	cd /etc
#	if grep -q "$private_address" hosts
#	then
#		juju-log "IBM WAS ND: Host file already updated"
#	else
#		juju-log "IBM WAS ND: Updating Host file"
#		echo "$private_address `hostname`" >> /etc/hosts
#	fi

	# Get the installable WAS ND resources
	juju-log "IBM WAS ND: fetching the ibm_was_nd_installer1 resource"
	status-set maintenance "fetching the ibm_was_nd_installer1 resource"
	cfg_was_nd_pkg1_name=`resource-get 'ibm_was_nd_installer1' || echo unavailable`
	
	juju-log "IBM WAS ND: fetching the ibm_was_nd_installer2 resource"
	status-set maintenance "fetching the ibm_was_nd_installer2 resource"
	cfg_was_nd_pkg2_name=`resource-get 'ibm_was_nd_installer2' || echo unavailable`
	
	ibm_was_pkg1_isempty=`file $cfg_was_nd_pkg1_name | { grep -q empty && echo "True"; } || echo "False"`
	ibm_was_pkg2_isempty=`file $cfg_was_nd_pkg2_name | { grep -q empty && echo "True"; } || echo "False"`
	ibm_was_pkg3_isempty=`file $cfg_was_nd_pkg3_name | { grep -q empty && echo "True"; } || echo "False"`
	
	if [ "$ARCHITECTURE" == "x86_64" ];then
		juju-log "IBM WAS ND: fetching the ibm_was_nd_installer3 resource"
		status-set maintenance "fetching the ibm_was_nd_installer3 resource"
		cfg_was_nd_pkg3_name=`resource-get 'ibm_was_nd_installer3' || echo unavailable`	  
		# If we don't have a package, report blocked status; we can't proceed.
		if [ "$cfg_was_nd_pkg1_name" = "unavailable" -o "$cfg_was_nd_pkg2_name" = "unavailable" -o "$cfg_was_nd_pkg3_name" = "unavailable" ]; then
			juju-log "IBM WAS ND: missing required ibm_was_nd_installer resource"
			status-set blocked "missing required ibm_was_nd_installer resource"
			exit 0
		fi
		
		if [ "$ibm_was_pkg1_isempty" = "True" -o "$ibm_was_pkg2_isempty" = "True" -o "$ibm_was_pkg3_isempty" = "True" ]; then
			juju-log "IBM WAS ND: missing required ibm_was_nd_installer resource, found empty packages"
			status-set blocked "missing required ibm_was_nd_installer resource, provide actual ibm_was_nd_installer resources."
			exit 0
		fi
		
	elif [ "$ARCHITECTURE" == "ppc64le" ];then
		# If we don't have a package, report blocked status; we can't proceed.
		if [ "$cfg_was_nd_pkg1_name" = "unavailable" -o "$cfg_was_nd_pkg2_name" = "unavailable" ]; then
			juju-log "IBM WAS ND: missing required ibm_was_nd_installer resource"
			status-set blocked "missing required ibm_was_nd_installer resource"
			exit 0
		fi
		if [ "$ibm_was_pkg1_isempty" = "True" -o "$ibm_was_pkg2_isempty" = "True" ]; then
			juju-log "IBM WAS ND: missing required ibm_was_nd_installer resource, found empty packages"
			status-set blocked "missing required ibm_was_nd_installer resource, provide actual ibm_was_nd_installer resources."
			exit 0
		fi
	fi
	
	juju-log "IBM WAS ND: using $cfg_was_nd_pkg1_name $cfg_was_nd_pkg2_name $cfg_was_nd_pkg3_name as the ibm_was_nd_installer resources"
	was_nd_installers="$cfg_was_nd_pkg1_name $cfg_was_nd_pkg2_name $cfg_was_nd_pkg3_name"
	juju-log "IBM WAS ND: was_nd_installers===$was_nd_installers"
	
	for was_pkg in $was_nd_installers; do
		juju-log "IBM WAS ND: was_pkg====="$was_pkg
		if [ -f $was_pkg ]; then
			ARCHIVE_DIR=`dirname $was_pkg`
			juju-log "IBM WAS ND: extracting the ibm_was_nd_installer resources"
			status-set maintenance "extracting the ibm_was_nd_installer resource"
			if [ -d $ARCHIVE_DIR/../WAS_ND/disk1 -a -d $ARCHIVE_DIR/../WAS_ND/disk2 -a -d $ARCHIVE_DIR/../WAS_ND/disk3 ];then
				juju-log "IBM WAS ND: ibm_was_nd_installer resources already extracted"
			else
				if [ ! -d $ARCHIVE_DIR/../WAS_ND ]; then
					mkdir $ARCHIVE_DIR/../WAS_ND
				fi				
				if ! unzip $was_pkg -d $ARCHIVE_DIR/../WAS_ND
				then
					juju-log "IBM WAS ND: Unable to extract the WAS ND packages content. Verify whether the package is corrupt."
					# Remove corrupt archive file
					status-set blocked "IBM WAS ND packages are corrupt"
					rm -rf $ARCHIVE_DIR/../WAS_ND 
					exit 0
				else
					juju-log "IBM WAS ND: $was_pkg extracted successfully"
				fi
			fi
		fi
	done
	
	juju-log "IBM WAS ND: starting WAS ND installation."
	status-set maintenance "IBM WAS ND: Installing WAS ND"
	#sh does not work in ubuntu so linking to bash
	juju-log "IBM WAS ND: Unlink /bin/sh"
	unlink /bin/sh
	ln -s /bin/bash /bin/sh
	if [ "$ARCHITECTURE" == "x86_64" ];then
		if $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.ND.v85 -acceptLicense -repositories $ARCHIVE_DIR/../WAS_ND -installationDirectory $WAS_ND_INSTALL_PATH  -showProgress
		then
			set_state 'ibm-was-nd.installed'
			status-set active "IBM WAS ND: WAS ND is installed successfully!"
		else
			status-set blocked "IBM WAS ND: WAS ND Installation failed!"
			exit 1
		fi
                          
	elif [ "$ARCHITECTURE" == "ppc64le" ];then
		if $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.ND.le.v85 -acceptLicense -repositories $ARCHIVE_DIR/../WAS_ND -installationDirectory $WAS_ND_INSTALL_PATH  -showProgress
		then
			set_state 'ibm-was-nd.installed'
			status-set active "IBM WAS ND: WAS ND is installed successfully!"
		else
			status-set blocked "IBM WAS ND: WAS ND Installation failed!"
			exit 1
		fi
	fi
              
}

reactive_handler_main
